@@ -8,14 +8,14 @@
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Bulk;
-$ElasticSearchX::Model::Bulk::VERSION = '0.1.9';
+$ElasticSearchX::Model::Bulk::VERSION = '0.2.0';
 use Search::Elasticsearch::Bulk;
 use Moose;
 
 has stash => (
-    is      => 'ro',
-    isa => "Search::Elasticsearch::Bulk",
-    handles => { stash_size => '_buffer_count', commit => "flush" },
+    is         => 'ro',
+    isa        => "Search::Elasticsearch::Bulk",
+    handles    => { stash_size => '_buffer_count', commit => "flush" },
     lazy_build => 1,
 );
 has size => ( is => 'ro', isa => 'Int', default => 100 );
@@ -27,35 +27,50 @@ sub _build_stash {
 }
 
 sub add {
-    my ($self, $action, $payload) = (shift, %{$_[0]});
+    my ( $self, $action, $payload ) = ( shift, %{ $_[0] } );
     $payload->{source} = delete $payload->{body};
-    $self->stash->add_action($action => $payload);
+    $self->stash->add_action( $action => $payload );
 }
 
 sub update {
     my ( $self, $doc, $qs ) = @_;
-    $self->add( { index => ref $doc eq 'HASH' ? $doc : { $doc->_put( $doc->_update($qs) ) } } );
+    $self->add(
+        {
+            index => ref $doc eq 'HASH'
+            ? $doc
+            : { $doc->_put( $doc->_update($qs) ) }
+        }
+    );
     return $self;
 }
 
 sub create {
     my ( $self, $doc, $qs ) = @_;
-    $self->add( { create => ref $doc eq 'HASH' ? $doc : { $doc->_put($qs) } } );
+    $self->add(
+        { create => ref $doc eq 'HASH' ? $doc : { $doc->_put($qs) } } );
     return $self;
 }
 
 sub put {
     my ( $self, $doc, $qs ) = @_;
-    $self->add( { index => ref $doc eq 'HASH' ? $doc : { $doc->_put, %{ $qs || {} } } } );
+    $self->add(
+        {
+            index => ref $doc eq 'HASH'
+            ? $doc
+            : { $doc->_put, %{ $qs || {} } }
+        }
+    );
     return $self;
 }
 
 sub delete {
     my ( $self, $doc, $qs ) = @_;
     $self->add(
-        {   delete => ref $doc eq 'HASH'
+        {
+            delete => ref $doc eq 'HASH'
             ? $doc
-            : { index => $doc->index->name,
+            : {
+                index => $doc->index->name,
                 type  => $doc->meta->short_name,
                 id    => $doc->_id,
             }
@@ -71,7 +86,8 @@ sub clear {
 }
 
 sub DEMOLISH {
-    shift->commit;
+    my $self = shift;
+    $self->commit if $self->has_stash;
 }
 
 1;
@@ -88,7 +104,7 @@ ElasticSearchX::Model::Bulk
 
 =head1 VERSION
 
-version 0.1.9
+version 0.2.0
 
 =head1 SYNOPSIS
 
