@@ -8,7 +8,7 @@
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Document::Trait::Attribute;
-$ElasticSearchX::Model::Document::Trait::Attribute::VERSION = '0.1.9';
+$ElasticSearchX::Model::Document::Trait::Attribute::VERSION = '0.2.0';
 # ABSTRACT: Trait that extends the meta class of a document class
 use Moose::Role;
 use ElasticSearchX::Model::Document::Mapping;
@@ -36,12 +36,16 @@ has property          => ( is => 'ro', isa => 'Bool', default => 1 );
 has query_property    => ( is => 'ro', isa => 'Bool', default => 0 );
 has field_name =>
     ( is => 'ro', isa => 'Str', lazy => 1, default => sub { shift->name } );
-has isa_arrayref =>
-    ( is => 'ro', lazy => 1, isa => 'Bool', builder => '_build_isa_arrayref' );
+has isa_arrayref => (
+    is      => 'ro',
+    lazy    => 1,
+    isa     => 'Bool',
+    builder => '_build_isa_arrayref'
+);
 
 sub _build_isa_arrayref {
     my $self = shift;
-    my $tc = $self->type_constraint;
+    my $tc   = $self->type_constraint;
     return 0 unless $tc;
     return $tc->is_a_type_of("ArrayRef");
 }
@@ -84,7 +88,7 @@ after _process_options => sub {
 sub mapping {
     my $self = shift;
     return ( $self->name => $self->build_property )
-        unless ( $self->source_only  || $self->parent );
+        unless ( $self->source_only || $self->parent );
     return ();
 }
 
@@ -92,7 +96,11 @@ sub type_mapping { () }
 
 after install_accessors => sub {
     my $self = shift;
-    return unless($self->associated_class->does_role('ElasticSearchX::Model::Document::Role'));
+    return
+        unless (
+        $self->associated_class->does_role(
+            'ElasticSearchX::Model::Document::Role')
+        );
     $self->associated_class->_add_field_alias(
         $self->name => $self->field_name );
     $self->associated_class->_add_reverse_field_alias(
@@ -113,7 +121,7 @@ ElasticSearchX::Model::Document::Trait::Attribute - Trait that extends the meta
 
 =head1 VERSION
 
-version 0.1.9
+version 0.2.0
 
 =head1 ATTRIBUTES
 
