@@ -8,25 +8,28 @@
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Document::Trait::Field::ID;
-$ElasticSearchX::Model::Document::Trait::Field::ID::VERSION = '0.1.9';
+$ElasticSearchX::Model::Document::Trait::Field::ID::VERSION = '0.2.0';
 use Moose::Role;
 use ElasticSearchX::Model::Document::Types qw(:all);
 
 has id => (
-    is     => 'rw',
-    isa    => 'ArrayRef|Bool',
+    is  => 'rw',
+    isa => 'ArrayRef|Bool',
 );
 
 after install_accessors => sub {
     my $self = shift;
-    return unless($self->associated_class->does_role('ElasticSearchX::Model::Document::Role'));
-    $self->associated_class->_add_reverse_field_alias(
-        _id => $self->name );
+    return
+        unless (
+        $self->associated_class->does_role(
+            'ElasticSearchX::Model::Document::Role')
+        );
+    $self->associated_class->_add_reverse_field_alias( _id => $self->name );
     $self->associated_class->_id_attribute($self);
 };
 
 package ElasticSearchX::Model::Document::Trait::Class::ID;
-$ElasticSearchX::Model::Document::Trait::Class::ID::VERSION = '0.1.9';
+$ElasticSearchX::Model::Document::Trait::Class::ID::VERSION = '0.2.0';
 use Moose::Role;
 
 1;
@@ -43,7 +46,7 @@ ElasticSearchX::Model::Document::Trait::Field::ID
 
 =head1 VERSION
 
-version 0.1.9
+version 0.2.0
 
 =head1 AUTHOR
 
