@@ -8,7 +8,7 @@
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Index;
-$ElasticSearchX::Model::Index::VERSION = '0.1.9';
+$ElasticSearchX::Model::Index::VERSION = '0.2.0';
 use Moose;
 use Module::Find ();
 use Class::Load  ();
@@ -57,7 +57,7 @@ sub _build_types {
     );
     map { Class::Load::load_class($_) } @found;
     @found = grep {
-        $_->isa('Moose::Object')
+               $_->isa('Moose::Object')
             && $_->does('ElasticSearchX::Model::Document::Role')
     } @found;
     return { map { $_->meta->short_name => $_->meta } @found };
@@ -89,7 +89,9 @@ sub deployment_statement {
     my $self   = shift;
     my $deploy = {};
     foreach my $type ( $self->get_types ) {
-        next if $type->does_role('ElasticSearchX::Model::Document::EmbeddedRole');
+        next
+            if $type->does_role(
+            'ElasticSearchX::Model::Document::EmbeddedRole');
         $deploy->{mappings}->{ $type->short_name } = $type->mapping;
     }
     my $model = $self->model->meta;
@@ -137,7 +139,7 @@ ElasticSearchX::Model::Index
 
 =head1 VERSION
 
-version 0.1.9
+version 0.2.0
 
 =head1 ATTRIBUTES
 
