@@ -8,7 +8,7 @@
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Scroll;
-$ElasticSearchX::Model::Scroll::VERSION = '0.1.9';
+$ElasticSearchX::Model::Scroll::VERSION = '0.2.0';
 use Moose;
 use Search::Elasticsearch::Scroll;
 
@@ -40,8 +40,9 @@ has qs => (
 sub _build__scrolled_search {
     my $self = shift;
     Search::Elasticsearch::Scroll->new(
-        {   es => $self->set->es,
-            body => $self->set->_build_query,
+        {
+            es     => $self->set->es,
+            body   => $self->set->_build_query,
             scroll => $self->scroll,
             index  => $self->index->name,
             type   => $self->type->short_name,
@@ -71,7 +72,7 @@ ElasticSearchX::Model::Scroll
 
 =head1 VERSION
 
-version 0.1.9
+version 0.2.0
 
 =head1 SYNOPSIS
 
