@@ -12,10 +12,11 @@ use Moose;
 use ElasticSearchX::Model::Document;
 use DateTime;
 
-has id        => ( is => 'ro', id  => [qw(user post_date)] );
-has user      => ( is => 'ro', isa => 'Str' );
-has name      => ( is => 'ro', isa => 'Str' );
-has post_date => ( is => 'ro', isa => 'DateTime', default => sub { DateTime->now } );
-has message   => ( is => 'rw', isa => 'Str', index => 'analyzed' );
+has id   => ( is => 'ro', id  => [qw(user post_date)] );
+has user => ( is => 'ro', isa => 'Str' );
+has name => ( is => 'ro', isa => 'Str' );
+has post_date =>
+    ( is => 'ro', isa => 'DateTime', default => sub { DateTime->now } );
+has message => ( is => 'rw', isa => 'Str', index => 'analyzed' );
 
-__PACKAGE__->meta->make_immutable;
\ No newline at end of file
+__PACKAGE__->meta->make_immutable;
